Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(139)

Unified Diff: third_party/WebKit/public/platform/WebSecurityOrigin.h

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/platform/mojo/SecurityOriginStructTraits.h ('k') | url/mojo/origin.mojom » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/platform/WebSecurityOrigin.h
diff --git a/third_party/WebKit/public/platform/WebSecurityOrigin.h b/third_party/WebKit/public/platform/WebSecurityOrigin.h
index 93c0aa4fdeea4b8b58bb33e24bdf53c65bbf79ea..5501a03b4645c80e009cc53c9267ac3a5448e245 100644
--- a/third_party/WebKit/public/platform/WebSecurityOrigin.h
+++ b/third_party/WebKit/public/platform/WebSecurityOrigin.h
@@ -78,7 +78,8 @@ class WebSecurityOrigin {
BLINK_PLATFORM_EXPORT WebString Suborigin() const;
// A unique WebSecurityOrigin is the least privileged WebSecurityOrigin.
BLINK_PLATFORM_EXPORT bool IsUnique() const;
// Returns true if this WebSecurityOrigin can script objects in the given
@@ -128,7 +129,7 @@ class WebSecurityOrigin {
}
WebSecurityOrigin(const url::Origin& origin) {
- if (origin.unique()) {
+ if (origin.opaque()) {
Assign(WebSecurityOrigin::CreateUnique());
return;
}
@@ -78,7 +78,8 @@ class WebSecurityOrigin {
BLINK_PLATFORM_EXPORT WebString Suborigin() const;
- // A unique WebSecurityOrigin is the least privileged WebSecurityOrigin.
+ // An opaque WebSecurityOrigin is the least privileged WebSecurityOrigin.
+ // TODO: Rename to IsOpaque
BLINK_PLATFORM_EXPORT bool IsUnique() const;
// Returns true if this WebSecurityOrigin can script objects in the given
« no previous file with comments | « third_party/WebKit/Source/platform/mojo/SecurityOriginStructTraits.h ('k') | url/mojo/origin.mojom » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698